.. large_image documentation master file, created by
   sphinx-quickstart on Tue Dec 31 14:43:10 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.

.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tilesource_options
   config_options
   image_conversion
   upgrade
   _build/large_image/modules
   _build/large_image_source_bioformats/modules
   _build/large_image_source_deepzoom/modules
   _build/large_image_source_dummy/modules
   _build/large_image_source_gdal/modules
   _build/large_image_source_mapnik/modules
   _build/large_image_source_nd2/modules
   _build/large_image_source_ometiff/modules
   _build/large_image_source_openjpeg/modules
   _build/large_image_source_openslide/modules
   _build/large_image_source_pil/modules
   _build/large_image_source_test/modules
   _build/large_image_source_tiff/modules
   _build/large_image_converter/modules
   _build/large_image_tasks/modules
   _build/girder_large_image/modules
   _build/girder_large_image_annotation/modules
   annotations
   development


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
